<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="500px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="busRef" :rules="state.formRules" label-width="150px" >
        <el-form-item label="所属公司:" prop="companyName" v-if="!state.isAdmin">
          <el-input v-model.trim="state.form.companyName" disabled></el-input>
        </el-form-item>
        <el-form-item label="批次名称:" prop="name">
          <el-input v-model.trim="state.form.name" placeholder="请输入批次名称"></el-input>
        </el-form-item>
        <el-form-item label="培训级别:" prop="level" >
          <el-select v-model="state.form.level" placeholder="请选择培训级别" style="width: 100%">
            <el-option
                v-for="item in state.levelList"
                :key="item.id"
                :label="item.name"
                style="width: 100%"
                :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="归属课程:" prop="courseName">
          <el-select
              v-model="state.form.courseName"
              style="width: 100%"
              v-loadMoreNew:[reselect]="handleScroll"
              :popper-class="reselect.name"
              @change="selectValue"
              class="item-width"
              placeholder="请选择课程"
          >
            <el-option
                v-for="item in state.courseList"
                :key="item.id"
                :label="item.name"
                :value="item.name"
            />
          </el-select>
        </el-form-item>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import {ElMessage} from "element-plus";

import {
  getClassification
} from "@/api/onlineEducation/courseClass";
import {
  addCourse,
  checkCourseName,
  editCourse,
  getApproveCourse,
  getCourse,
  getCourseById
} from "@/api/onlineEducation/courseManage";
import {getToken} from "@/utils/auth";
import {delPic, getBannerById} from "@/api/onlineEducation/banner";
import Cookies from "js-cookie";
import {
  addQuestionBank,
  checkQuestionBankName,
  editQuestionBank,
  getQuestionBank
} from "@/api/onlineEducation/questionBank";
import {addBatch, checkBatchName, editBatch} from "@/api/onlineEducation/batch";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const length = ref()
const emit = defineEmits(["getList"]);
const startUsername = ref('');
const classifyRef = ref(null)
const reselect = reactive({
  name: 'course1'
})
const validateName = (rule, value, callback)=>{
  if(value === ''){
    callback(new Error('请输入批次名称'))
  }else if(title.value === '编辑' && value === startUsername.value){
    callback()
  }else{
    let param = {}
    if(title.value === '新增') {
      param = {
        name:value
      }
    }else if(title.value === '编辑'){
      param = {
        name:value,
        id: state.form.id
      }
    }
    checkBatchName(param).then((res)=>{
      if(res.data == false){
        callback(new Error('批次名称已被占用，请更换其他名称'))
      }else{
        callback()
      }
    })
  }
}
const state = reactive({
  form: {
    id: '',
    name: '',
    courseId: null,
    companyName: '',
    courseName: '',
    companyId: null,
    level: null
  },
  formRules: {
    companyName:[{required: true,message: '', trigger: 'blur'}],
    name: [{required: true, trigger: "blur", validator: validateName}],
    courseName: [{required: true, message: '请选择课程', trigger: 'blur'}],
    level: [{required: true, message: '请选择培训级别', trigger: 'blur'}],
  },
  classifyList: [],
  isAdmin: false,
  levelList: [
    {
      id: 1,
      name: '公司级 '
    },
    {
      id: 2,
      name: '部门级'
    },
    {
      id: 3,
      name: '车间级'
    },
    {
      id: 4,
      name: '其他'
    },
  ],
  courseList: [],
  courseNum: 1,
  courseSize: 10,
  hasMoreItems: null, // 是否还有更多选项

})

const openDialog = async (type, value) => {
  await loadMoreCourseData();
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  console.log("userInfo",userInfo)
  if(userInfo.userType === 0){
    state.isAdmin = true;
    state.form.companyName = ''
    state.form.companyId = null
  }else {
    state.isAdmin = false;
    state.form.companyName = userInfo.companyName
    state.form.companyId = userInfo.companyId
  }
  title.value = type === 'addFirst' || type === 'add' ? '新增' : type ==='edit' ? '编辑' : '' ;
  if(type === 'edit') {
    startUsername.value = value.name;
    state.form = value;
  }
  dialogVisible.value = true;
}
const handleScroll = () => {
  if(state.courseNum >= state.hasMoreItems) return
  state.courseNum++;
  loadMoreCourseData()
}

const selectValue = (val) => {
  state.courseList.forEach(item => {
    if(item.name === val){
      state.form.courseId = item.id
    }
  })
}
const loadMoreCourseData = async () => {
  const queryParams = {
    pageNum: state.courseNum,
    pageSize: state.courseSize,
  }
  const res = await getApproveCourse(queryParams)
  if (res.code == 200) {
    state.hasMoreItems = res.data.totalPage
    const data = res.data.list.filter(item => item.status == 0)
    state.courseList = state.courseList.concat(data)
  }else{
    ElMessage.warning(res.message)
  }
}

const onSubmit = async () => {
  // if(state.isAdmin){
  //   ElMessage({
  //     type: 'warning',
  //     message: '管理员暂无权限'
  //   });
  //   return;
  // }
  const valid = await busRef.value.validate();
  if(valid){
    if(title.value === '新增'){
      const {id,courseName,companyName, ...data} = JSON.parse(JSON.stringify(state.form))
      const res = await addBatch(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '新增成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }else if(title.value === '编辑'){
      const {courseName,companyName,...data} = JSON.parse(JSON.stringify(state.form))
      const res = await editBatch(data)
      if(res.code === 200){
        ElMessage({
          type: 'success',
          message: '编辑成功'
        });
      }else{
        ElMessage.warning(res.message)
      }
      emit("getList")
      busRef.value.clearValidate();
      reset();
      dialogVisible.value = false;
    }
  }
}

const handleClose = () => {
  busRef.value.clearValidate();
  reset();
  dialogVisible.value = false;
  emit("getList")

}
const reset = () => {
  state.form = {
    id: '',
    name: '',
    courseId: null,
    companyName: '',
    companyId: null,
    level: null,
    courseName: ''
  }
  state.courseNum = 1;
  state.courseSize = 10;
  state.courseList = []
}
defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
